Module: Unmagic::Enum::ActiveRecordExtensions::InstanceMethods
- Defined in:
- lib/unmagic/enum/active_record_extensions.rb
Instance Method Summary collapse
-
#to_type_for_database ⇒ Object
Support for ActiveRecord type casting in SQL queries This allows Enum instances to be used directly in where clauses.
Instance Method Details
#to_type_for_database ⇒ Object
Support for ActiveRecord type casting in SQL queries This allows Enum instances to be used directly in where clauses
74 75 76 |
# File 'lib/unmagic/enum/active_record_extensions.rb', line 74 def to_type_for_database @value end |